@@ -17,6 +17,7 @@ xlab <- "Time (in days)"
 lxlab <- paste0(xlab, " on log-scale")
 ylabS <- "Probability of survival"
 ylablHaz <- "Log-cumulative hazard"
+ylabcumHR <- expression(Lambda[1](t)/Lambda[0](t))
 ylimS <- c(0, 1)
 ylimHR <- c(0, 1.6)
 q <- 0:2204
@@ -69,7 +70,7 @@ frmtll <- function(x, math = FALSE, mark = FALSE) {
     if (is.na(x)) return("")
   ret <- frmt2(abs(x), math = FALSE)
   if (x < 0) ret <- paste0(ifelse(math, "$-$", "-"), ret)
-  if (mark) ret <- paste0("{\\color{gray}", ret, "}")
+  if (mark) ret <- paste0("{\\color{darkgray}", ret, "}")
   ret
 }
 
@@ -93,16 +94,15 @@ lslevs <- gsub("cT4", "cT4    ", lslevs)
 ## id
 CAOsurv$id <- factor(1:nrow(CAOsurv))
 
-
 ## ----pars, include = FALSE----------------------------------------------------
 par_main <- expression(par(mgp = c(2.5, 1, 0), mar = c(4, 4, 1.5, 4), las = 1))
 par_surv <- expression(par(mgp = c(2.5, 1, 0), mar = c(6, 6, .5, 4), las = 1))
 
 
+
 ## ----packages, echo = FALSE---------------------------------------------------
 library("tram")
 
-
 ## ----risk-tab-----------------------------------------------------------------
 risktab <- function(ti, st) { ## time-index and survival time
   nrisk <- NULL
@@ -120,7 +120,6 @@ mtext(risktab(ti, CAOsurv[CAOsurv$randarm == levs[2], tvar]),
   side = 1, line = 5, at = ti, cex = cex)
 }
 
-
 ## ----surv-OS------------------------------------------------------------------
 surv_OS <- survfit(OS ~ randarm, data = CAOsurv) ## KM
 
@@ -129,11 +128,16 @@ surv_OS <- survfit(OS ~ randarm, data = CAOsurv) ## KM
 surv_iDFS <- survfit(iDFS ~ randarm, data = CAOsurv) ## Turnbull
 
 
+
+
+
+
 ## ----CAO-table, results = 'hide'----------------------------------------------
 tab <- xtabs( ~ strat + randarm, data = CAOsurv)
 tab <- rbind(tab, "Total" = colSums(tab))
 
 
+
 ## ----surv-iDFS-plot-----------------------------------------------------------
 eval(par_surv)
 plot(surv_iDFS, ylim = ylimS, xlim = xlim,
@@ -160,7 +164,8 @@ summary(mw)
 coef(mw, as.survreg = TRUE) ## same interpretation as "survreg"
 score_test(mw)
 perm_test(mw)
-plot(as.mlt(mw), type = "survivor", newdata = nd1, col = col)
+# plot(as.mlt(mw), type = "survivor", newdata = nd1, col = col)
+
 
 
 ## ----COX-model-fit, echo = FALSE, cache = TRUE--------------------------------
@@ -172,7 +177,8 @@ Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
 summary(mc)
 score_test(mc)
 perm_test(mc)
-plot(as.mlt(mc), type = "survivor", newdata = nd1, col = col)
+# plot(as.mlt(mc), type = "survivor", newdata = nd1, col = col)
+
 
 
 ## ----COX-lHaz, echo = FALSE---------------------------------------------------
@@ -199,7 +205,6 @@ cb <- confint(multcomp::glht(multcomp::parm(coef(object),
         "calpha"))$confint
 cb <- cbind(q, cb)
 
-
 ## ----COX-lHaz-plot------------------------------------------------------------
 eval(par_main)
 plot(cb[, "q"], cb[, "Estimate"], log = "x", type = "n",
@@ -211,6 +216,7 @@ polygon(c(cb[, "q"], rev(cb[, "q"])), c(cb[, "lwr"], rev(cb[, "upr"])),
 lines(cb[, "q"], cb[, "Estimate"], lwd = lwd)
 
 
+
 ## ----STRAT-model-fit, cache = TRUE--------------------------------------------
 mcst <- 
 Coxph(iDFS | strat ~ randarm, data = CAOsurv, log_first = TRUE)
@@ -231,6 +237,8 @@ legend("bottomright", legend = lslevs, title = "Stratum",
   lty = lty, lwd = lwd, col = 1, bty = "n")
 
 
+
+
 ## ----SCOX-model-fit, cache = TRUE---------------------------------------------
 mcs <- 
 Coxph(iDFS ~ randarm | randarm, data = CAOsurv, log_first = TRUE)
@@ -238,26 +246,28 @@ Coxph(iDFS ~ randarm | randarm, data = CAOsurv, log_first = TRUE)
 
 ## ----SCOX-summary, cache = TRUE, results = "hide", fig.show = "hide"----------
 summary(mcs)
+confint(mcs)
 perm_test_biv.stram(mcs)
-plot(as.mlt(mcs), type = "survivor", newdata = nd1, col = col)
+# plot(as.mlt(mcs), type = "survivor", newdata = nd1, col = col)
 
 
 ## ----SCOX-HR-plot, echo = FALSE-----------------------------------------------
 qHR <- seq(50, max(q), by = 1)
 cumhaz <- predict(mcs, type = "cumhazard", newdata = nd1, q = qHR)
 cumhr <- unname(cumhaz[, 2] / cumhaz[, 1])
-plot(qHR, cumhr, type = "l", ylab = expression(Lambda[1]*Lambda[0]^{-1}), xlab = xlab,
+plot(qHR, cumhr, type = "l", ylab = ylabcumHR, xlab = xlab,
   ylim = ylimHR, xlim = xlimHR <- range(qHR), lwd = lwd)
 
 abline(h = exp(coef(mc)), lty = 2, lwd = 1) ## constant HR
 abline(h = 1, lty = 3) ## HR = 1
 
 
+
+
 ## ----TCOX-model-fit, cache = TRUE---------------------------------------------
 mcv <- 
 Coxph(iDFS | randarm ~ 1, data = CAOsurv, log_first = TRUE)
 
-
 ## ----TCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'----------
 logLik(mcv)
 
@@ -265,8 +275,8 @@ logLik(mcv)
 ## ----TCOX-HR, cache = TRUE----------------------------------------------------
 mcv <- as.mlt(mcv)
 
-## grid
-s <- mkgrid(mcv, 500)
+## grid (was n = 500, qmvnorm failed)
+s <- mkgrid(mcv, 40)
 s$iDFS <- s$iDFS[s$iDFS >= min(xlimHR) & s$iDFS <= max(xlimHR)]
 nd3 <- expand.grid(s)
 
@@ -281,10 +291,9 @@ coxy <- s$iDFS
 ## confint for constant HR
 ci2 <- exp(confint(mc))
 
-
 ## ----TCOX-HR-plot-------------------------------------------------------------
 plot(coxy, ci[, "Estimate"], ylim = ylimHR, type = "n",
-  xlim = xlimHR, xlab = xlab, ylab = expression(Lambda[1]*Lambda[0]^{-1}))
+  xlim = xlimHR, xlab = xlab, ylab = ylabcumHR)
 polygon(c(coxy, rev(coxy)), c(ci[,"lwr"], rev(ci[, "upr"])),
         border = NA, col = rgb(.1, .1, .1, .1))
 lines(coxy, ci[, "Estimate"], lty = 1, lwd = lwd)
@@ -325,6 +334,8 @@ tab <- xtabs(~ nDepCevent + randarm, data = CAOsurv)
 tab
 
 
+
+
 ## ----DEPCENS-model-fit, cache = TRUE------------------------------------------
 md <- 
 Coxph(Surv(OStime, event = DepCevent) ~ randarm, data = CAOsurv)
@@ -344,9 +355,11 @@ confint(md)
 library("tramME")
 
 
+
 ## ----COXME-model-fit, cache = TRUE--------------------------------------------
 mcME <- 
-CoxphME(iDFS ~ randarm + (1 | Block), data = CAOsurv, log_first = TRUE)
+CoxphME(iDFS ~ randarm + (1 | Block), data = CAOsurv,
+  log_first = TRUE)
 
 
 ## ----COXME-summary, cache = TRUE, results = "hide", fig.show = 'hide'---------
@@ -354,6 +367,8 @@ summary(mcME)
 confint(mcME)
 
 
+
+
 ## ----COXME-margsurv, eval = FALSE---------------------------------------------
 ## ## computationally intensive
 ## if (!file.exists("ME-margdist.rda")) {
@@ -411,6 +426,7 @@ mtram(Coxph(iDFS2 ~ randarm, data = CAOsurv, log_first = TRUE),
 
 ## ----MCOX-FUN-----------------------------------------------------------------
 ## marginal HR from "mtram"
+## <FIXME> reset seed on.exit </FIXME>
 mHR.mtram <- function(object, with_confint = FALSE, seed = 1) {
   stopifnot(inherits(object, "mtram"))
   cf <- coef(object)
@@ -419,43 +435,51 @@ mHR.mtram <- function(object, with_confint = FALSE, seed = 1) {
   mlHR <- cf[1] / sqrt(1 + cf["gamma1"]^2)
   ret <- mHR <- exp(mlHR)
   if (with_confint) {
-  set.seed(seed)
-  object <- update(object, Hessian = TRUE)
-  H <- object$Hessian
-  S <- solve(H + .1 * diag(nrow(H)))
-  rbeta <- rmvnorm(10000, mean = coef(object), sigma = S)
-  s <- rbeta[,ncol(rbeta)]
-  rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
-  ci <- quantile(exp(rbeta[, ncol(rbeta)]), prob = c(.025, .975))
-  ret <- c(mHR, ci)
-  ret <- as.array(t(ret))
+    set.seed(seed)
+    S <- vcov(object)
+    rbeta <- rmvnorm(10000, mean = coef(object), sigma = S)
+    s <- rbeta[,ncol(rbeta)]
+    rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
+    ci <- quantile(exp(rbeta[, ncol(rbeta)]), prob = c(.025, .975))
+    ret <- c(mHR, ci)
+    ret <- as.array(t(ret))
   }
   return(ret)
 }
 
-
 ## ----MCOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'----------
 coef(mmc)
 sqrt(diag(vcov(mmc)))
 (ci_MCOX <- mHR.mtram(mmc, with_confint = TRUE))
 
 
+
 ## ----HTECOX-model-fit, cache = TRUE-------------------------------------------
 ma <- 
-CoxphME(iDFS ~ randarm + s(age, by = as.ordered(randarm), fx = TRUE, k = 6),
-  data = CAOsurv, log_first = TRUE)
-sma <- smooth_terms(ma)
-hr <- exp(sma[[1]]["s(age)"] + coef(ma))[,, drop = TRUE]
-age <- sma[[1]]$age
+CoxphME(iDFS ~ randarm + s(age, by = as.ordered(randarm),
+    fx = TRUE, k = 6), data = CAOsurv, log_first = TRUE)
+nd <- model.frame(ma)[rep(2, 100), ]
+nd$age <- seq(min(CAOsurv$age), max(CAOsurv$age), length.out = 100)
+xx <- model.matrix(ma, data = nd, type = "X", keep_sign = FALSE)$X
+ip <- grep("randarm", names(bb <- coef(ma, with_baseline = TRUE)))
+vc <- vcov(ma, parm = names(bb)[ip])
+bb <- bb[ip]
 
+## NOTE: unadjusted
+cb <- exp(confint(multcomp::glht(multcomp::parm(bb, vc), linfct = xx),
+                  calpha = univariate_calpha())$confint)
 
 ## ----HTECOX-summary, cache = TRUE, results = "hide", fig.show = 'hide'--------
 summary(ma)
 
 
 ## ----HTECOX-HR-plot-----------------------------------------------------------
-plot(age, hr, type = "l", ylab = "Hazard ratio", xlab = "Age (in years)",
-  ylim = ylimHR, lwd = lwd)
+## Plot HR
+plot(nd$age, cb[, "Estimate"], type = "n", ylab = "Hazard ratio", xlab = "Age (in years)",
+     ylim = ylimHR)
+polygon(c(nd$age, rev(nd$age)), c(cb[, "lwr"], rev(cb[, "upr"])),
+        border = NA, col = rgb(.1, .1, .1, .1))
+lines(nd$age, cb[, "Estimate"], lwd = lwd)
 abline(h = 1, lty = 3)
 rug(CAOsurv$age, lwd = 2, col = rgb(.1, .1, .1, .1))
 
@@ -485,6 +509,7 @@ plot(rotate(tr), tp_args = list(newdata = nd1, type = "survivor", col = col, lwd
   terminal_panel = trtf:::node_mlt)
 
 
+
 ## ----FRAILTY-model-fit, cache = TRUE------------------------------------------
 mf <- 
 Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE, frailty = "Gamma")
@@ -497,6 +522,7 @@ coef(mf, addparm = TRUE)
 confint(mf, parm = c(trt, "logrho"))
 
 
+
 ## ----LOGIT-model-fit----------------------------------------------------------
 ml <- 
 Colr(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
@@ -507,8 +533,7 @@ Colr(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
 ## additional packages
 pkgs <- c("fastGHQuad", "icenReg", "TransModel", "rms", "ICsurv", "eha",
   "rstpm2", "flexsurv", "mpr", "gamlss", "gamlss.cens", 
-  "coxme", "parfm", "frailtyEM", "frailtypack", "timereg")
-
+  "coxme", "parfm", "frailtyEM", "frailtypack", "mgcv", "timereg")
 
 ## ----install-pkgs-------------------------------------------------------------
 ix <- which(!sapply(pkgs, require, char = TRUE))
@@ -521,6 +546,7 @@ if (length(ix) > 0) {install.packages(pkgs[ix], repos = "https://stat.ethz.ch/CR
 Surv <- survival::Surv ## masked by eha
 
 
+
 ## ----result-summary, include = FALSE------------------------------------------
 frmtcall <- function(mod, call = NA, tex = TRUE) {
   pkg <- NA
@@ -593,6 +619,7 @@ tab <- function(mod, parm = trt, math = TRUE, mark = TRUE, tex = TRUE) {
   
   cfint <- switch(call["Call"],
     "coxph" = "log-HR", "Coxph" = "log-HR", "CoxphME" = "log-HR", 
+    "gam" = ifelse(mod$family$family == "Cox PH", "log-HR", NA),
     "coxme" = "log-HR", "frailtyPenal" = "log-HR", "emfrail" = "log-HR",
     "survreg" = "log-AF", "Survreg" = "log-HR",
     "stpm2" = ifelse(identical(mod@link$link, link.stpm2.ph, ignore.environment = TRUE),
@@ -606,8 +633,8 @@ tab <- function(mod, parm = trt, math = TRUE, mark = TRUE, tex = TRUE) {
   if (inherits(mod, c("stram", "mpr", "gamlss"))) cfint <- NA
   if (is.null(cfint)) cfint <- NA
   
-  mark <- ifelse(mark && inherits(mod, c("coxph", "coxme", "cph", "ic_sp", "ic_ph", "ic_po", 
-    "cox.aalen", "emfrail", "flexurvspline", "frailtyPenal")), TRUE, FALSE)
+  mark <- ifelse(mark && call["Call"] %in% c("gam", "coxph", "coxme", "cph", "ic_sp", "ic_ph", "ic_po", 
+    "cox.aalen", "emfrail", "frailtyPenal"), TRUE, FALSE)
   ret <- c(cfint, frmt3(cf, math = math), frmt3(se, math = math),
     frmtll(ll, mark = mark, math = math))
   names(ret) <- n <- c("Interpretation", "Estimate", "Std. Error", "logLik")
@@ -620,11 +647,14 @@ print.results <- function(objects) {
 }
 
 
+
+
 ## ----WEI-iDFS-fit, cache = TRUE-----------------------------------------------
 mwi1 <- tram::Survreg(iDFS ~ randarm, data = CAOsurv, dist = "weibull")
 mwi2 <- icenReg::ic_par(iDFS ~ randarm, data = CAOsurv, dist = "weibull",
   model = "ph")
-mwi3 <- flexsurv::flexsurvreg(iDFS ~ randarm, data = CAOsurv, dist = "weibullPH")
+mwi3 <- flexsurv::flexsurvreg(iDFS ~ randarm, data = CAOsurv,
+  dist = "weibullPH")
 mwi4 <- survival::survreg(iDFS ~ randarm, data = CAOsurv, dist = "weibull")
 mwi5 <- icenReg::ic_par(iDFS ~ randarm, data = CAOsurv, dist = "weibull",
   model = "aft") 
@@ -646,8 +676,8 @@ with(CAOsurv, all.equal(Surv(time = iDFStime, time2 = iDFStime2, event = iDFSeve
 
 ## ----Cox-iDFS-fit, echo = FALSE, cache = TRUE---------------------------------
 mci1 <- tram::Coxph(iDFS ~ randarm, data = CAOsurv, log_first = TRUE)
-mci2 <- rstpm2::stpm2(Surv(time = iDFStime, time2 = iDFStime2, event = iDFSevent,
-    type = "interval") ~ randarm, data = CAOsurv, log.time.transform = TRUE)
+mci2 <- rstpm2::stpm2(Surv(time = iDFStime, time2 = iDFStime2,
+  event = iDFSevent, type = "interval") ~ randarm, data = CAOsurv)
 mci3 <- flexsurv::flexsurvspline(iDFS ~ randarm, data = CAOsurv, k = 3)
 mci4 <- icenReg::ic_sp(iDFS ~ randarm, data = CAOsurv, model = "ph")
 
@@ -656,6 +686,8 @@ mci4 <- icenReg::ic_sp(iDFS ~ randarm, data = CAOsurv, model = "ph")
 print.results(list(mci1, mci2, mci3, mci4))
 
 
+
+
 ## ----Cox-DFS-fit, echo = FALSE, cache = TRUE----------------------------------
 mc1 <- tram::Coxph(DFS ~ randarm, data = CAOsurv, log_first = TRUE)
 mc2 <- survival::coxph(DFS ~ randarm, data = CAOsurv)
@@ -666,17 +698,29 @@ mc3 <- rms::cph(DFS ~ randarm, data = CAOsurv)
 print.results(list(mc1, mc2, mc3))
 
 
+
+
+
+
+
+
 ## ----STRAT-iDFS-fit, cache = TRUE---------------------------------------------
 mstci1 <- tram::Coxph(iDFS | strat ~ randarm, data = CAOsurv, log_first = TRUE)
 mstci2 <- rstpm2::stpm2(Surv(time = iDFStime, time2 = iDFStime2, event = iDFSevent,
-    type = "interval") ~ randarm + strata(strat),
-  data = CAOsurv, log.time.transform = TRUE)
-mstci3 <- flexsurv::flexsurvspline(iDFS ~ randarm + gamma1(strat) + gamma2(strat),
-  data = CAOsurv, k = 3)
+    type = "interval") ~ randarm + strata(strat), data = CAOsurv)
+mstci3 <- NULL
+#mstci3 <- flexsurv::flexsurvspline(iDFS ~ randarm + gamma1(strat) + gamma2(strat),
+#  data = CAOsurv, k = 3, control=list(ndeps=rep(1e-09,12)))
+## COMMENT: "flexsurv" package: look at plot(model)
+## control: necessary for flexsurv 2.3; see email by Nov 4
+##          by Chris Jackson
+##          however, the hessian is singular, so we exclude this model
+##          for the time being.
 
 
 ## ----STRAT-iDFS-results-------------------------------------------------------
-print.results(list(mstci1, mstci2, mstci3))
+print.results(list(mstci1, mstci2))##, mstci3))
+
 
 
 ## ----STRAT-DFS-fit, cache = TRUE----------------------------------------------
@@ -689,6 +733,7 @@ mstc3 <- rms::cph(DFS ~ randarm + strat(strat), data = CAOsurv)
 print.results(list(mstc1, mstc2, mstc3))
 
 
+
 ## ----STRAT-Wei-iDFS-fit, echo = FALSE, cache = TRUE---------------------------
 mstw1 <- tram::Survreg(DFS | strat ~ randarm, data = CAOsurv)
 mstw2 <- eha::phreg(DFS ~ randarm + strata(strat), data = CAOsurv)
@@ -699,6 +744,8 @@ mstw3 <- survival::survreg(DFS ~ randarm + strata(strat), data = CAOsurv)
 print.results(list(mstw1, mstw2, mstw3))
 
 
+
+
 ## ----LS-iDFS-Wei-fit, cache = TRUE--------------------------------------------
 mswi1 <- tram::Survreg(iDFS ~ randarm | randarm, data = CAOsurv,
   remove_intercept = FALSE)
@@ -709,26 +756,33 @@ mswi2 <- gamlss::gamlss(formula = iDFS ~ randarm, sigma.fo = ~ randarm,
   data = tmp, control = gamlss.control(n.cyc = 300, trace = FALSE))
 
 
+
 ## ----LS-iDFS-results----------------------------------------------------------
 print.results(list(mswi1, mswi2))
 
 
+
+
 ## ----LS-DFS-fit, echo = FALSE, cache = TRUE-----------------------------------
 msw1 <- tram::Survreg(DFS ~ randarm | randarm, data = CAOsurv,
   remove_intercept = FALSE)
 msw2 <- mpr::mpr(DFS ~ list(~ randarm, ~ randarm), data = CAOsurv)
 
 
+
 ## ----LS-DFS-results-----------------------------------------------------------
 print.results(list(msw1, msw2))
 
 
+
+
 ## ----TVAR-iDFS-fit, cache = TRUE----------------------------------------------
 mcvi1 <- tram::Coxph(iDFS | randarm ~ 1, data = CAOsurv)
 mcvi2 <- flexsurv::flexsurvspline(iDFS ~ randarm +
     gamma1(randarm) + gamma2(randarm), data = CAOsurv, k = 3)
 
 
+
 ## ----TVAR-iDFS-plot, fig.width = 6, fig.height = 3----------------------------
 ## cumHR from "tram"
 xlim.tvar <- c(100, max(q))
@@ -742,7 +796,7 @@ cumhr <- cumhaz[,2] / cumhaz[,1]
 
 par(mgp = c(2.5, 1, 0), mar = c(4, 4, 1.5, 4))
 plot(s[[y]], cumhr, ylim = ylimHR, type = "l",
-     xlab = xlab, ylab = expression(Lambda[1]*Lambda[0]^{-1}), las = 1, lwd = lwd)
+     xlab = xlab, ylab = ylabcumHR, las = 1, lwd = lwd)
 abline(h = 1, lty = 3)
 
 ## cumHR from "flexsurvspline"
@@ -757,6 +811,7 @@ legend("topright", lty = 1:2, lwd = 2, col = c("black", col2),
   bty = "n")
 
 
+
 ## ----TVAR-DFS-fit, cache = TRUE-----------------------------------------------
 mcv1 <- tram::Coxph(DFS | randarm ~ 1, data = CAOsurv, log_first = TRUE)
 mcv2 <- flexsurv::flexsurvspline(DFS ~ randarm + gamma1(randarm) + gamma2(randarm),
@@ -776,7 +831,7 @@ cumhr <- cumhaz[,2] / cumhaz[,1]
 
 par(mgp = c(2.5, 1, 0), mar = c(4, 4, 1.5, 4))
 plot(s[[y]], cumhr, ylim = ylimHR, type = "l",
-     xlab = xlab, ylab =  expression(Lambda[1]*Lambda[0]^{-1}), las = 1, lwd = lwd)
+     xlab = xlab, ylab =  ylabcumHR, las = 1, lwd = lwd)
 abline(h = 1, lty = 3)
 
 ## cumHR from "flexsurvspline"
@@ -791,6 +846,7 @@ legend("topright", lty = 1:2, lwd = 2, col = c("black", col2),
   bty = "n")
 
 
+
 ## ----MIXED-DFS-fit, cache = TRUE----------------------------------------------
 mcME1 <- tramME::CoxphME(DFS ~ randarm + (1 | Block), data = CAOsurv, log_first = TRUE)
 mcME2 <- rstpm2::stpm2(Surv(DFStime, DFSevent) ~ randarm, data = CAOsurv,
@@ -802,28 +858,71 @@ mcME3 <- coxme::coxme(DFS ~ randarm + (1 | Block), data = CAOsurv)
 print.results(list(mcME1, mcME2, mcME3))
 
 
+
+
+## ----HTECOX-DFS-fit-----------------------------------------------------------
+ma1 <- CoxphME(DFS ~ randarm +
+    s(age, by = as.ordered(randarm), fx = TRUE, k = 6),
+               data = CAOsurv, log_first = TRUE)
+ma2 <- gam(DFStime ~ randarm +
+    s(age, by = as.ordered(randarm), fx = TRUE, k = 6),
+               data = CAOsurv, family = cox.ph(), weights = DFSevent)
+
+
+## ----HTECOX-DFS-results-------------------------------------------------------
+print.results(list(ma1, ma2))
+
+
+## ----HTECOX-DFS-plot----------------------------------------------------------
+nd <- model.frame(ma1)[rep(2, 100), ]
+nd$age <- seq(min(CAOsurv$age), max(CAOsurv$age), length.out = 100)
+xx <- model.matrix(ma1, data = nd, type = "X", keep_sign = FALSE)$X
+ip <- grep("randarm", names(bb <- coef(ma1, with_baseline = TRUE)))
+vc <- vcov(ma1, parm = names(bb)[ip])
+bb <- bb[ip]
+
+cb1 <- exp(confint(multcomp::glht(multcomp::parm(bb, vc), linfct = xx),
+                  calpha = univariate_calpha())$confint)
+
+plot(nd$age, cb1[, "Estimate"], type = "n", ylab = "Hazard ratio", xlab = "Age (in years)",
+     ylim = ylimHR)
+matlines(nd$age, cb1, lwd = lwd, col = 1, lty = 1)
+abline(h = 1, lty = 3)
+
+summary(ma2)
+
+nd2 <- model.frame(ma2)[rep(2, 100), ]
+nd2$age <- seq(min(CAOsurv$age), max(CAOsurv$age), length.out = 100)
+pr <- predict(ma2, newdata = nd2, type = "link", se.fit = TRUE)
+
+matlines(nd2$age, exp(c(pr$fit) + qnorm(0.975) * pr$se.fit %o% c(0, -1, 1)),
+         col = col2, lwd = lwd, lty = 2)
+
+legend("bottomright", lty = 1:2, lwd = 2, col = c("black", col2),
+  legend = c(bquote("package:"~bold("tramME")), bquote("package:"~bold("mgcv"))),
+  bty = "n")
+
+
+
 ## ----FRAILTY-DFS-fit, cache = TRUE--------------------------------------------
-mfc1 <- tram::Coxph(DFS ~ randarm, data = CAOsurv, frailty = "Gamma",
-  log_first = TRUE)
-mfc2 <- rstpm2::stpm2(Surv(DFStime, DFSevent) ~ randarm, cluster = "id", 
-  data = CAOsurv, RandDist = "Gamma", log.time.transform = TRUE)
-mfc3 <- survival::coxph(DFS ~ randarm +
-    frailty(id, distribution = "gamma"), data = CAOsurv)
+mfc1 <- tram::Coxph(DFS ~ randarm, data = CAOsurv, log_first = TRUE, frailty = "Gamma")
+mfc2 <- rstpm2::stpm2(Surv(DFStime, DFSevent) ~ randarm, data = CAOsurv,
+  cluster = "id", RandDist = "Gamma")
+mfc3 <- survival::coxph(DFS ~ randarm + frailty(id, distribution = "gamma"), data = CAOsurv)
 mfc4 <- frailtyEM::emfrail(DFS ~ randarm + cluster(id), data = CAOsurv)
-mfc5 <- frailtypack::frailtyPenal(DFS ~ randarm + cluster(id),
-  data = CAOsurv, RandDist = "Gamma", n.knots = 6, kappa = 1000)
- frailtypack::frailtyPenal(DFS ~ randarm,
-  data = CAOsurv, n.knots = 6, kappa = 1000)
+mfc5 <- frailtypack::frailtyPenal(DFS ~ randarm + cluster(id), data = CAOsurv,
+  RandDist = "Gamma", n.knots = 10, kappa = 1)
 
 
 ## ----FRAILTY-DFS-results------------------------------------------------------
 print.results(list(mfc1, mfc2, mfc3, mfc4, mfc5))
 
 
+
+
 ## ----Colr-DFS-fit, cache = TRUE-----------------------------------------------
 mo1 <- tram::Colr(DFS ~ randarm, data = CAOsurv, log_first = TRUE)
-mo2 <- rstpm2::stpm2(Surv(DFStime, DFSevent) ~ randarm, data = CAOsurv,
-  log.time.transform = TRUE, link.type = "PO")
+mo2 <- rstpm2::stpm2(Surv(DFStime, DFSevent) ~ randarm, data = CAOsurv, link.type = "PO")
 mo3 <- flexsurv::flexsurvspline(iDFS ~ randarm, data = CAOsurv, k = 3, scale = "odds")
 mo4 <- timereg::Gprop.odds(DFS ~ prop(randarm), data = CAOsurv)
 
@@ -835,4 +934,3 @@ print.results(list(mo1, mo2, mo3, mo4))
 ## ----session, results = "markup"----------------------------------------------
 sessionInfo()
 
-
