@@ -1,9 +1,29 @@
-## ----mtram-setup, echo = FALSE, results = "hide", message = FALSE, warning = FALSE----
+## ----mtram-pkgs, echo = FALSE, results = "hide", message = FALSE, warning = FALSE----
 set.seed(290875)
 
-pkgs <- sapply(c("mlt", "survival", "tram", "lme4", "gridExtra", 
-         "lattice", "latticeExtra", "mvtnorm", "ordinalCont"), require, char = TRUE)
+pkgs <- c("colorspace", "survival", "lme4", "tram", "gridExtra",
+          "lattice", "latticeExtra", "mvtnorm", "ordinalCont", "tramME")
+pkgs <- sapply(pkgs, require, character.only = TRUE)
 
+## ----mtram-citation, echo = FALSE---------------------------------------------
+year <- substr(packageDescription("tram")$Date, 1, 4)
+version <- packageDescription("tram")$Version
+
+## ----fail, results = "asis", echo = FALSE-------------------------------------
+if (any(!pkgs))
+{
+    cat(paste("Package(s)", paste(names(pkgs)[!pkgs], collapse = ", "), 
+        "not available, stop processing.",
+        "\\end{document}\n"))
+    knitr::knit_exit()
+}
+if (!interactive() && .Platform$OS.type != "unix")
+{
+    cat("Vignette only compiled under Unix alikes.")
+    knitr::knit_exit()
+}
+
+## ----mtram-setup, echo = FALSE, results = "hide", message = FALSE, warning = FALSE----
 trellis.par.set(list(plot.symbol = list(col=1,pch=20, cex=0.7),
                      box.rectangle = list(col=1),
                      box.umbrella = list(lty=1, col=1),
@@ -63,36 +83,25 @@ mypanel <- function (x, y, f.value = NULL, type = "s", groups = NULL, qtype = 7,
         }
     }
 }
-library("colorspace")
 col <- diverge_hcl(2, h = c(246, 40), c = 120, l = c(65, 90), alpha = .75)
 
-## ----mtram-citation, echo = FALSE----------------------------------------
-year <- substr(packageDescription("tram")$Date, 1, 4)
-version <- packageDescription("tram")$Version
-
-## ----fail, results = "asis", echo = FALSE--------------------------------
-if (any(!pkgs))
-{
-    cat(paste("Package(s)", paste(names(pkgs)[!pkgs], collapse = ", "), 
-        "not available, stop processing.",
-        "\\end{document}\n"))
-    knitr::knit_exit()
-}
-
 ## ----mtram-vignette, eval = FALSE----------------------------------------
-#  install.packages("tram")
-#  vignette("mtram", package = "tram")
+# install.packages("tram")
+# demo("mtram", package = "tram")
 
 ## ----mtram-sleep-plot, echo = FALSE--------------------------------------
+library("lme4")
 xyplot(Reaction ~ Days | Subject, data = sleepstudy, 
        xlab = "Days of sleep deprivation", ylab = "Average reaction time (in ms)")
 
-## ----mtram-sleep_lmer, cache = TRUE--------------------------------------
-library("lme4")
+## ----mtram-sleep_lmer, cache = FALSE-------------------------------------
 sleep_lmer <- lmer(Reaction ~ Days + (Days | Subject), 
                    data = sleepstudy, REML = FALSE)
 
-## ----mtram-sleep_mtram, cache = TRUE-------------------------------------
+## ----mtram-tram----------------------------------------------------------
+library("tram")
+
+## ----mtram-sleep_mtram, cache = FALSE------------------------------------
 sleep_LM <- Lm(Reaction ~ Days, data = sleepstudy)
 sleep_LMmer <- mtram(sleep_LM, ~ (Days | Subject), data = sleepstudy)
 
@@ -123,7 +132,7 @@ sleepstudy$Reaction_I <- with(sleepstudy, Surv(Reaction - 20, Reaction + 20,
                                                type = "interval2"))
 sleepstudy$Reaction_I[1:5]
 
-## ----mtram-sleep-interval, cache = TRUE----------------------------------
+## ----mtram-sleep-interval, cache = FALSE---------------------------------
 sleep_LM_I <- Lm(Reaction_I ~ Days, data = sleepstudy)
 sleep_LMmer_I <- mtram(sleep_LM_I, ~ (Days | Subject), data = sleepstudy)
 
@@ -132,10 +141,9 @@ logLik(sleep_LMmer_I)
 coef(sleep_LMmer_I)
 coef(sleep_LMmer)
 
-## ----mtram-sleep_BoxCox, cache = TRUE------------------------------------
+## ----mtram-sleep_BoxCox, cache = FALSE-----------------------------------
 sleep_BC <- BoxCox(Reaction ~ Days, data = sleepstudy)
-sleep_BCmer <- mtram(sleep_BC, ~ (Days | Subject), data = sleepstudy, 
-                     Hessian = TRUE)
+sleep_BCmer <- mtram(sleep_BC, ~ (Days | Subject), data = sleepstudy)
 logLik(sleep_BCmer)
 
 ## ----mtram-sleep_BoxCoxPlot, echo = FALSE, fig.height = 5----------------
@@ -150,7 +158,7 @@ rug(sleepstudy$Reaction, col = rgb(.1, .1, .1, .1))
 days <- 0:9
 q <- seq(from = min(sleepstudy$Reaction), to = max(sleepstudy$Reaction), 
          length.out = 100)
-meth <- c("Normal linear mixed-effects model", "Non-norma linear transformation model")
+meth <- c("Normal linear mixed-effects model", "Non-normal linear transformation model")
 ex <- expand.grid(Reaction = q, Days = days,
                   Method = factor(meth, levels = meth, labels = meth))
 U <- cbind(1, days)
@@ -185,13 +193,14 @@ grey <- rgb(.75, .75, .75)
 nd <- ex
 plotfun("prob", ex, layout = c(5, 2), par.settings = simpleTheme(col=c(grey, col), lwd = 3),
   auto.key = list(text = c("Empirical cumulative distribution function", levels(nd$Method)), 
-                  points = FALSE, lines = TRUE))
+                  points = FALSE, lines = TRUE, space = "top"))
 
 ## ----mtram-sleep_corr----------------------------------------------------
 cov2cor(sleep_BCmer$G)
 
 ## ----mtram-sleep_vcov----------------------------------------------------
-VC <- solve(sleep_BCmer$Hessian)
+library("mvtnorm")
+VC <- vcov(sleep_BCmer)
 idx <- (nrow(VC) - 2):nrow(VC)
 Rcoef <- rmvnorm(1000, mean = coef(sleep_BCmer), sigma = VC)[,idx]
 ret <- apply(Rcoef, 1, function(gamma) {
@@ -208,12 +217,65 @@ quantile(ret[2,], c(.025, .5, .975))
 ### correlation random intercept / random slope
 quantile(ret[3,], c(.025, .5, .975))
 
-## ----mtram-toenail-plot, echo = FALSE------------------------------------
+## ----mtram-sleep_Colr, cache = FALSE-------------------------------------
+sleep_C <- Colr(Reaction ~ Days, data = sleepstudy)
+sleep_Cmer <- mtram(sleep_C, ~ (Days | Subject), data = sleepstudy)
+logLik(sleep_Cmer)
+
+## ----mtram-sleep_marginal-2, fig.height = 5, fig.width = 7, echo = FALSE----
+days <- 0:9
+q <- seq(from = min(sleepstudy$Reaction), to = max(sleepstudy$Reaction), 
+         length.out = 100)
+meth <- c("Normal linear mixed-effects model", "Probit transformation model", 
+          "Marginal logit transformation model")
+ex <- expand.grid(Reaction = q, Days = days,
+                  Method = factor(meth, levels = meth, labels = meth))
+U <- cbind(1, days)
+### Linear
+tmp <- as.mlt(sleep_LM)
+cf <- coef(tmp)
+coef(tmp) <- coef(sleep_LMmer)[names(cf)]
+SLM <- tcrossprod(U %*% as(sleep_BCmer$G, "matrix"), U) + diag(nrow(U))
+sd <- sqrt(diag(SLM))
+h <- predict(tmp, newdata = data.frame(Days = days), q = q, type = "trafo")
+prob_LM <- pnorm(t(t(h) / sd ))
+### BoxCox
+tmp <- as.mlt(sleep_BC)
+cf <- coef(tmp)
+coef(tmp) <- coef(sleep_BCmer)[names(cf)]
+SBC <- tcrossprod(U %*% as(sleep_BCmer$G, "matrix"), U) + diag(nrow(U))
+sd <- sqrt(diag(SBC))
+h <- predict(tmp, newdata = data.frame(Days = days), q = q, type = "trafo")
+prob_BC <- pnorm(t(t(h) / sd ))
+### Colr
+tmp <- as.mlt(sleep_C)
+cf <- coef(tmp)
+coef(tmp) <- coef(sleep_Cmer)[names(cf)]
+SBC <- tcrossprod(U %*% as(sleep_Cmer$G, "matrix"), U) + diag(nrow(U))
+sd <- sqrt(diag(SBC))
+h <- predict(tmp, newdata = data.frame(Days = days), q = q, type = "trafo")
+prob_C <- plogis(t(t(h) / sd ))
+ex$prob <- c(prob_LM, prob_BC, prob_C)
+plotfun <- function(prob, data, ...) {
+    fm <- as.formula(paste(prob, "~ Reaction | Days"))
+    xyplot(fm, data = data, type = "l", 
+        panel = function(x, y, subscripts, ...) {
+            tmp <- subset(sleepstudy, Days == unique(nd[subscripts, "Days"]))
+            mypanel(tmp$Reaction, rep(1, nrow(tmp)), lwd = 3, col = grey)
+            panel.xyplot(x, y, subscripts = subscripts, ...)
+    }, col = c(col, col[2]),  xlab = "Average reaction time (in ms)", 
+    ylab = "Marginal distribution function", lwd = 2, groups = Method, lty =
+    c(1, 1, 3), ...)
+}
+grey <- rgb(.75, .75, .75)
+nd <- ex
+plotfun("prob", ex, layout = c(5, 2), par.settings = simpleTheme(col=c(grey, col, col[2]), lwd =
+3, lty = c(1, 1, 1, 3)),
+  auto.key = list(text = c("Empirical cumulative distribution function", levels(nd$Method)), 
+                  points = FALSE, lines = TRUE, space = "top"))
+
+## ----mtram-toenail-plot, echo = FALSE, cache = FALSE---------------------
 data("toenail", package = "HSAUR3")
-rlev <- levels(toenail$patientID)[xtabs(~ patientID, 
-                                        data = toenail) == 1]
-toenail <- subset(toenail, !patientID %in% rlev)
-toenail$patientID <- toenail$patientID[, drop = TRUE]
 layout(matrix(1:2, ncol = 2))
 trt <- levels(toenail$treatment)
 cdplot(outcome ~ time, data = subset(toenail, treatment == trt[1]),
@@ -221,7 +283,7 @@ cdplot(outcome ~ time, data = subset(toenail, treatment == trt[1]),
 cdplot(outcome ~ time, data = subset(toenail, treatment == trt[2]),
        main = trt[2], xlab = "Time", ylab = "")
 
-## ----mtram-toenail_glmer_RI, cache = TRUE--------------------------------
+## ----mtram-toenail_glmer_RI, cache = FALSE-------------------------------
 ### Laplace
 toenail_glmer_RI_1 <- 
     glmer(outcome ~ treatment * time + (1 | patientID),
@@ -238,69 +300,115 @@ toenail_glmer_RI_2 <-
 summary(toenail_glmer_RI_2)
 toenail_glmer_RI_2@theta
 
-## ----mtram-toenail_mtram_RI, cache = TRUE--------------------------------
+## ----mtram-toenail_glmmTMB_RI, cache = FALSE-----------------------------
+library("glmmTMB")
+toenail_glmmTMB_RI_3 <- 
+    glmmTMB(outcome ~ treatment * time + (1 | patientID),
+         data = toenail, family = binomial(link = "probit"))
+summary(toenail_glmmTMB_RI_3)
+
+## ----mtram-toenail_mtram_RI, cache = FALSE-------------------------------
 m <- ctm(as.basis(~ outcome, data = toenail), 
          shifting = ~ treatment * time, 
-         data = toenail, todistr = "Normal")
+         data = toenail, todistr = "Normal", negative = TRUE)
 toenail_probit <- mlt(m, data = toenail, 
                       fixed = c("outcomemoderate or severe" = 0))
 toenail_mtram_RI <- 
-    mtram(toenail_probit, ~ (1 | patientID), 
-          data = toenail, Hessian = TRUE)
-logLik(toenail_mtram_RI)
+    mtram(toenail_probit, ~ (1 | patientID), data = toenail)
 coef(toenail_mtram_RI)
 
 ## ----mtram-toenail-hessian-----------------------------------------------
 vcov(toenail_glmer_RI_2)
-solve(toenail_mtram_RI$Hessian)[1:4, 1:4]
+vcov(toenail_mtram_RI)[1:4, 1:4]
 
-## ----mtram-toenail_glmer_RS, cache = TRUE--------------------------------
-toenail_glmer_RS <- 
-    glmer(outcome ~ treatment * time + (1 + time | patientID),
-          data = toenail, family = binomial(link = "probit"))
-summary(toenail_glmer_RS)
-toenail_glmer_RS@theta
+## ----mtram-toenail-coef--------------------------------------------------
+cf <- coef(toenail_mtram_RI)
+cf[2:4] / sqrt(1 + cf["gamma1"]^2)
 
-## ----mtram-toenail_mtram_RS, cache = TRUE--------------------------------
-toenail_mtram_RS <- 
-    mtram(toenail_probit, ~ (1 + time | patientID), 
-          data = toenail)
-logLik(toenail_mtram_RS)
-coef(toenail_mtram_RS)
+## ----mtram-toenail-gee-probit--------------------------------------------
+library("geepack")
+gin <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, corstr = "independence", 
+              family = binomial(link = "probit"))
+gex <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, cor = "exchangeable", 
+              family = binomial(link = "probit"))
+gun <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, cor = "unstructured", 
+              family = binomial(link = "probit"))
 
-## ----mtram-toenail_logit, cache = TRUE-----------------------------------
+## ----mtram-toenail-gee-probit-coef---------------------------------------
+cbind(mtram = cf[2:4] / sqrt(1 + cf["gamma1"]^2),
+      indep = coef(gin)[-1],
+      excha = coef(gex)[-1],
+      unstr = coef(gun)[-1])
+
+## ----mtram-toenail-gee-logit---------------------------------------------
+gin <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, corstr = "independence", 
+              family = binomial())
+gex <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, cor = "exchangeable", 
+              family = binomial())
+gun <- geeglm(I((0:1)[outcome]) ~ treatment * time, 
+              id = patientID, data = toenail, cor = "unstructured", 
+              family = binomial())
+
+## ----mtram-toenail-gee-logit-coef----------------------------------------
+coef(gin)
+coef(gex)
+coef(gun)
+
+## ----mtram-toenail_logit, cache = FALSE----------------------------------
 m <- ctm(as.basis(~ outcome, data = toenail), 
          shifting = ~ treatment * time, 
-         data = toenail, todistr = "Logistic")
+         data = toenail, todistr = "Logistic", negative = TRUE)
 toenail_logit <- mlt(m, data = toenail, 
                      fixed = c("outcomemoderate or severe" = 0))
 toenail_mtram_logit <- mtram(toenail_logit, ~ (1 | patientID), 
-                              data = toenail)
-toenail_mtram_logit_s <- mtram(toenail_logit, ~ (1 | patientID), 
-                               data = toenail, standardise = TRUE, 
-                               Hessian = TRUE)
+                             data = toenail)
+
+## ----mtram-toenail_logit-coef--------------------------------------------
+cf <- coef(toenail_mtram_logit)
+cf[2:4] / sqrt(1 + cf["gamma1"]^2)
+
+## ----mtram-toenail-trt---------------------------------------------------
+S <- rmvnorm(10000, mean = coef(toenail_mtram_logit), 
+             sigma = vcov(toenail_mtram_logit))
+(ci <- quantile(S[,"treatmentterbinafine:time"] / sqrt(1 + S[, "gamma1"]^2), 
+                prob = c(.025, .975)))
+
+## ----mtram-toenail-gee-logit-mcoef---------------------------------------
+cbind(mtram = cf[2:4] / sqrt(1 + cf["gamma1"]^2),
+      indep = coef(gin)[-1],
+      excha = coef(gex)[-1],
+      unstr = coef(gun)[-1])
+
+## ----mtram-GEE-CI--------------------------------------------------------
+exp(coef(gun)["treatmentterbinafine:time"] +
+    c(-1, 1) * qnorm(.975) * sqrt(diag(vcov(gun)))["treatmentterbinafine:time"])
 
 ## ----mtram-toenail_marginal_logit_s--------------------------------------
 tmp <- toenail_logit
 cf <- coef(tmp)
 cf <- cf[names(cf) != "outcomemoderate or severe"]
-sdrf <- rev(coef(toenail_mtram_logit_s))[1]
-cf <- coef(toenail_mtram_logit_s)[names(cf)] / sqrt(sdrf^2 + 1)
+sdrf <- rev(coef(toenail_mtram_logit))[1]
+cf <- coef(toenail_mtram_logit)[names(cf)] / sqrt(sdrf^2 + 1)
 cf <- c(cf[1], "outcomemoderate or severe" = 0, cf[-1])
 coef(tmp) <- cf
 time <- 0:180/10
 treatment <- sort(unique(toenail$treatment))
 nd <- expand.grid(time = time, treatment = treatment)
-nd$prob_logit_s <- predict(tmp, newdata = nd, type = "distribution")[1,]
+nd$prob_logit <- predict(tmp, newdata = nd, type = "distribution")[1,]
 nd$odds <- exp(predict(tmp, newdata = nd, type = "trafo")[1,])
 
-## ----mtram-toenail_OR_2, dev = "png", cache = TRUE, echo = FALSE, dpi = 300----
+## ----mtram-toenail_OR_2, dev = "png", cache = FALSE, echo = FALSE, dpi = 300----
 X <- model.matrix(~ treatment * time, data = nd)
-rbeta <- rmvnorm(10000, mean = coef(toenail_mtram_logit_s), 
-                 sigma = solve(toenail_mtram_logit_s$Hessian))
+rbeta <- rmvnorm(10000, mean = coef(toenail_mtram_logit), 
+                 sigma = vcov(toenail_mtram_logit))
 s <- rbeta[,ncol(rbeta)]
 rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
-odds <- exp(X %*% t(rbeta))
+odds <- exp(-X %*% t(rbeta))
 OR <- odds[1:length(time),] / odds[-(1:length(time)),]
 plot(time, rep(0, length(time)), ylim = range(OR), type = "n", 
      xlab = "Time", ylab = "Odds ratio")
@@ -331,18 +439,152 @@ coef(tmp) <- cf
 nd$prob_probit <- predict(tmp, newdata = nd, type = "distribution")[1,]
 
 ## ----mtram-toenail_probplot, echo = FALSE--------------------------------
-nd2 <- nd[rep(1:nrow(nd), 3),]
-nd2$prob <- c(nd$prob_probit, nd$prob_logit_s, nd$prob_logit)
-lev <- c("Probit (M1) = (M2)", "Logit (M1)", "Logit (M2)")
+nd2 <- nd[rep(1:nrow(nd), 2),]
+nd2$prob <- c(nd$prob_probit, nd$prob_logit)
+lev <- c("Probit", "Logit")
 nd2$model <- rep(factor(lev, labels = lev, levels = lev), each = nrow(nd))
 
 xyplot(prob ~ time | model, data = nd2, group = treatment, ylim = c(0, 1), 
        xlab = "Time", 
-       par.settings = simpleTheme(col=col),
+       par.settings = simpleTheme(col = col),
        auto.key = list(text = levels(nd2$treatment), 
-                       points = FALSE, lines = TRUE), 
+                       points = FALSE, lines = TRUE, space = "top"), 
        col = col, type = "l", ylab = "Probability (none or mild)")
 
+## ----mtram-toenail-subset------------------------------------------------
+(rlev <- levels(toenail$patientID)[xtabs(~ patientID, 
+                                        data = toenail) == 1])
+toenail_gr1 <- subset(toenail, !patientID %in% rlev)
+toenail_gr1$patientID <- toenail_gr1$patientID[, drop = TRUE]
+
+## ----mtram-toenail_glmer_RS, cache = FALSE-------------------------------
+toenail_glmer_RS <- 
+    glmer(outcome ~ treatment * time + (1 + time | patientID),
+          data = toenail_gr1, family = binomial(link = "probit"))
+summary(toenail_glmer_RS)
+toenail_glmer_RS@theta
+
+## ----mtram-toenail_glmmTMB_RS, cache = FALSE-----------------------------
+toenail_glmmTMB_RS_1 <- 
+    glmmTMB(outcome ~ treatment * time + (1 + time | patientID),
+         data = toenail_gr1, family = binomial(link = "probit"))
+summary(toenail_glmmTMB_RS_1)
+
+## ----mtram-toenail_mtram_RS, cache = FALSE-------------------------------
+m <- ctm(as.basis(~ outcome, data = toenail_gr1), 
+         shifting = ~ treatment * time, 
+         data = toenail, todistr = "Normal", negative = TRUE)
+toenail_probit <- mlt(m, data = toenail_gr1, 
+                      fixed = c("outcomemoderate or severe" = 0))
+toenail_mtram_RS <- 
+    mtram(toenail_probit, ~ (1 + time | patientID), 
+          data = toenail_gr1)
+logLik(toenail_mtram_RS)
+coef(toenail_mtram_RS)
+
+## ----toenail-comparisons, cache = FALSE, echo = FALSE, results = "hide"----
+t1 <- system.time(toenail_glmer_RI_1 <- 
+    glmer(outcome ~ treatment * time + (1 | patientID),
+          data = toenail, family = binomial(link = "probit"), 
+          nAGQ = 1))
+
+t2 <- system.time(toenail_glmer_RI_2 <- 
+    glmer(outcome ~ treatment * time + (1 | patientID),
+          data = toenail, family = binomial(link = "probit"), 
+          nAGQ = 20))
+
+t3 <- system.time(toenail_glmmTMB_RI_3 <- 
+    glmmTMB(outcome ~ treatment * time + (1 | patientID),
+         data = toenail, family = binomial(link = "probit")))
+
+m <- ctm(as.basis(~ outcome, data = toenail), 
+         shifting = ~ treatment * time, 
+         data = toenail, todistr = "Normal", negative = TRUE)
+toenail_probit <- mlt(m, data = toenail, 
+                      fixed = c("outcomemoderate or severe" = 0))
+t4 <- system.time(toenail_mtram_RI <- 
+    mtram(toenail_probit, ~ (1 | patientID), data = toenail))
+
+t5 <- system.time(toenail_glmer_RS <- 
+    glmer(outcome ~ treatment * time + (1 + time | patientID),
+          data = toenail_gr1, family = binomial(link = "probit")))
+
+t6 <- system.time(toenail_glmmTMB_RS_1 <- 
+    glmmTMB(outcome ~ treatment * time + (1 + time | patientID),
+         data = toenail_gr1, family = binomial(link = "probit")))
+
+m <- ctm(as.basis(~ outcome, data = toenail_gr1), 
+         shifting = ~ treatment * time, 
+         data = toenail, todistr = "Normal", negative = TRUE)
+toenail_probit <- mlt(m, data = toenail_gr1, 
+                      fixed = c("outcomemoderate or severe" = 0))
+t7 <- system.time(toenail_mtram_RS <- 
+    mtram(toenail_probit, ~ (1 + time | patientID), 
+           data = toenail_gr1))
+
+## ----output, echo = FALSE------------------------------------------------
+tn_RI_glmer_L <- c(fixef(toenail_glmer_RI_1), toenail_glmer_RI_1@theta, 0, 0)
+tn_RI_glmer_A <- c(fixef(toenail_glmer_RI_2), toenail_glmer_RI_2@theta, 0, 0)
+tn_RI_glmmTMB <- c(fixef(toenail_glmmTMB_RI_3)$cond, sqrt(VarCorr(toenail_glmmTMB_RI_3)$cond$patientID), 0, 0)
+tn_RI_mlt <- c(coef(toenail_mtram_RI), 0, 0)
+tn_RS_glmer <- c(fixef(toenail_glmer_RS), toenail_glmer_RS@theta)
+tn_RS_glmmTMB <- c(fixef(toenail_glmer_RS), chol(VarCorr(toenail_glmmTMB_RS_1)$cond$patientID)[c(1,3, 4)])
+tn_RS_mlt <- coef(toenail_mtram_RS)
+tn <- cbind(tn_RI_glmer_L, tn_RI_glmer_A , tn_RI_glmmTMB, tn_RI_mlt ,
+            tn_RS_glmer, tn_RS_glmmTMB, tn_RS_mlt)
+
+logLik(toenail_glmer_RI_1)
+logLik(toenail_glmer_RI_2)
+logLik(toenail_glmmTMB_RI_3)
+logLik(toenail_mtram_RI)
+
+logLik(toenail_glmer_RS)
+logLik(toenail_glmmTMB_RS_1)
+logLik(toenail_mtram_RS)
+
+ll <- c(
+### logLik of transformation model for glmer (Laplace) parameters
+logLik(toenail_mtram_RI, tn_RI_glmer_L[1:5] * c(-1, 1, 1, 1, 1)),
+### logLik of transformation model for glmer (AGQ) parameters
+logLik(toenail_mtram_RI, tn_RI_glmer_A[1:5] * c(-1, 1, 1, 1, 1)),
+### logLik of transformation model for glmmTMB (Laplace) parameters
+logLik(toenail_mtram_RI, tn_RI_glmmTMB[1:5] * c(-1, 1, 1, 1, 1)),
+### logLik of transformation model
+logLik(toenail_mtram_RI),
+### logLik of transformation model for glmer (Laplace) parameters
+logLik(toenail_mtram_RS, tn_RS_glmer * c(-1, rep(1, 6))),
+### logLik of transformation model for glmmTMB (Laplace) parameters
+logLik(toenail_mtram_RS, tn_RS_glmmTMB * c(-1, rep(1, 6))),
+### logLik of transformation model
+logLik(toenail_mtram_RS))
+
+tm <- c(t1["user.self"],
+        t2["user.self"],
+        t3["user.self"],
+        t4["user.self"],
+        t5["user.self"],
+        t6["user.self"],
+        t7["user.self"])
+tm <- formatC(tm, format = "f", digits = 2, width = 5)
+
+tn <- formatC(tn, format = "f", digits = 2, width = 5)
+ll <- formatC(ll, format = "f", digits = 2, width = 6)
+tn <- cbind(c("$\\alpha$", "$\\eshiftparm_1$", "$\\eshiftparm_2$", "$\\eshiftparm_3$", "$\\gamma_1$", "$\\gamma_2$", "$\\gamma_3$"), tn)
+ret <- c("
+\\begin{tabular}{lrrrr|rrr} \\\\ \\hline
+& \\multicolumn{4}{c|}{RI} & \\multicolumn{3}{c}{RI + RS} \\\\
+& \\texttt{glmer} & \\texttt{glmer} & \\texttt{glmmTMB} &  & \\texttt{glmer} & \\texttt{glmmTMB} & \\\\
+& L               & AGQ             & L & (7) & L & L & (7) \\\\ \\hline")
+ret <- c(ret, apply(tn, 1, function(x) c(paste(x, collapse = " & "), "\\\\")))
+ret <- c(ret, "\\hline")
+ret <- c(ret, 
+         paste("LogLik &", paste(ll, collapse = "&"), "\\\\ "), 
+         paste("Time (sec)   &", paste(tm, collapse = "&"), "\\\\ \\hline"), 
+         "\\end{tabular}")
+
+## ----table, echo = FALSE, results = "asis"-------------------------------
+cat(ret, sep = "\n")
+
 ## ----mtram-neck_plot, echo = FALSE, fig.height = 4, fig.width = 7--------
 data("neck_pain", package = "ordinalCont")
 pain_df <- neck_pain
@@ -360,8 +602,10 @@ p1 <- xyplot(vas ~ time | laser, data = pain,
        ylab = "Neck pain (on visual analog scale)", xlab = "Examinations")
 plot(p1)
 
-## ----mtram-neck_ocm, cache = TRUE, results = "hide"----------------------
+## ----mtram-ordinalCont---------------------------------------------------
 library("ordinalCont")
+
+## ----mtram-neck_ocm, cache = FALSE, results = "hide"---------------------
 neck_ocm <- ocm(vas ~ laser * time + (1 | id), data = pain_df, 
                 scale = c(0, 1))
 
@@ -371,13 +615,19 @@ summary(neck_ocm)
 ## ----mtram-neck_ocm_ci---------------------------------------------------
 exp(cbind(coef(neck_ocm)[2:6], confint(neck_ocm)[2:6,]))
 
-## ----mtram-neck_Colr, cache = TRUE---------------------------------------
+## ----tramME-neck---------------------------------------------------------
+library("tramME")
+neck_ColrME <- ColrME(vas ~ laser * time + (1 | id), data = pain_df, 
+                      bounds = c(0, 1), support = c(0, 1))
+
+## ----tramME-neck_ci------------------------------------------------------
+exp(coef(neck_ColrME))
+
+## ----mtram-neck_Colr, cache = FALSE--------------------------------------
 neck_Colr <- Colr(vas ~ laser * time, data = pain_df, 
                   bounds = c(0, 1), support = c(0, 1),
                   extrapolate = TRUE)
-neck_Colrmer <- mtram(neck_Colr, ~ (1 | id), data = pain_df, 
-                      Hessian = TRUE)
-logLik(neck_Colrmer)
+neck_Colrmer <- mtram(neck_Colr, ~ (1 | id), data = pain_df)
 
 ## ----mtram-neck_Colr_distr, echo = FALSE, fig.height = 4, fig.width = 7----
 nd <- expand.grid(laser = unique(pain_df$laser),
@@ -387,25 +637,85 @@ coef(tmp)[] <- coef(neck_Colrmer)[1:12]
 q <- 1:99/100
 nd2 <- expand.grid(vas = q, laser = unique(pain_df$laser),
                    time = unique(pain_df$time))
-tmp <- as.mlt(neck_Colr)
+# tmp <- as.mlt(neck_Colr) 
 sd <- sqrt(coef(neck_Colrmer)[13]^2 + 1)
 prb <- predict(tmp, newdata = nd, type = "distribution", q = q)
 nd2$prob <- c(pnorm(qnorm(prb) / sd))
 p2 <- xyplot(prob ~ vas | time, data = nd2, groups = laser, type = "l", 
-       col = col, 
-       layout = c(3, 1),
-       xlab = "Neck pain (on visual analog scale)", 
-       ylab = "Marginal distribution", 
-       par.settings = simpleTheme(col=col),
-       auto.key = list(text = levels(nd2$laser), 
-                       points = FALSE, lines = TRUE))
+             col = col, 
+             layout = c(3, 1),
+             xlab = "Neck pain (on visual analog scale)", 
+             ylab = "Marginal distribution", 
+             par.settings = simpleTheme(col=col),
+             auto.key = list(text = levels(nd2$laser), 
+                             points = FALSE, lines = TRUE, space = "top"))
 plot(p2)
 
+## M1
+# neck_Colrmer <- mtram(neck_Colr, ~ (1 | id), data = pain_df, 
+#                       Hessian = TRUE, standardise = FALSE)
+# logLik(neck_Colrmer)
+# 
+# nd <- expand.grid(laser = unique(pain_df$laser),
+#                   time = unique(pain_df$time))
+# q <- 1:99/100
+# nd2 <- expand.grid(vas = q, laser = unique(pain_df$laser),
+#                    time = unique(pain_df$time))
+# tmp <- as.mlt(neck_Colr)
+# coef(tmp)[] <- coef(neck_Colrmer)[1:12]
+# sd <- sqrt(coef(neck_Colrmer)[13]^2 + 1)
+# prb <- predict(tmp, newdata = nd, type = "distribution", q = q)
+# nd2$prob <- c(pnorm(qnorm(prb) / sd))
+# p2 <- xyplot(prob ~ vas | time, data = nd2, groups = laser, type = "l", 
+#              col = col, ylim = c(-0.05, 1.05),
+#              layout = c(3, 1),
+#              xlab = "Neck pain (on visual analog scale)", 
+#              ylab = "Marginal distribution", 
+#              par.settings = simpleTheme(col=col),
+#              auto.key = list(text = levels(nd2$laser), 
+#                              points = FALSE, lines = TRUE, space = "top"))
+# plot(p2)
+
+## ----mtram-neck_Colr-CI, echo = TRUE, eval=TRUE--------------------------
+S <- vcov(neck_Colrmer)
+rbeta <- rmvnorm(10000, mean = coef(neck_Colrmer), sigma = S)
+s <- rbeta[, ncol(rbeta)]
+rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
+t(apply(rbeta[, 8:12], 2, function(x) {
+  quantile(exp(x),prob = c(.025, .5, .975))}))
+
+## ----mtram-neck_Colr-std_beta--------------------------------------------
+beta <- coef(neck_Colrmer)[8:12]
+alpha <- coef(neck_Colrmer)[13]
+(std_beta <- cbind(beta / sqrt(1 + alpha^2)))
+
+## ----mtram-neck_Colr-ctr_mat---------------------------------------------
+ctr_mat <- matrix(c(1, 0, 0, 0, 0,
+                    1, 0, 0, 1, 0,
+                    1, 0, 0, 0, 1), nrow = 3, byrow = TRUE)
+ctr_mat %*% std_beta
+
+## ----mtram-neck_PImanual, eval=TRUE--------------------------------------
+(ci_emp <- t(apply(ctr_mat %*% t(rbeta[, 8:12]), 1, function(x) {
+  quantile(x, prob = c(.025, .5, .975))})))
+
+PI(-ci_emp, link = "logistic")
+
+## ----neck_Colr-PI, echo = TRUE-------------------------------------------
+nd <- expand.grid(time = unique(pain_df$time),
+                  laser = unique(pain_df$laser))
+neck_Colr_marg <- neck_Colr
+neck_Colr_marg$coef <- coef(neck_Colrmer)[1:12] / 
+                       sqrt(coef(neck_Colrmer)[13]^2 + 1)
+(neck_Colr_PI <- PI(neck_Colr_marg, newdata = nd[1:3, ], 
+                    reference = nd[4:6, ],
+                    one2one = TRUE, conf.level = .95))[1:3, 1:3]
+
 ## ----mtram-CAO, echo = FALSE---------------------------------------------
 dir <- system.file("rda", package = "TH.data")
 load(file.path(dir, "Primary_endpoint_data.rda"))
 
-## ----mtram-CAO-plot, cache = TRUE, echo = FALSE--------------------------
+## ----mtram-CAO-plot, cache = FALSE, echo = FALSE-------------------------
 ra <- sort(unique(CAOsurv$randarm))
 st <- sort(unique(CAOsurv$strat_t))
 sn <- sort(unique(CAOsurv$strat_n))
@@ -425,7 +735,7 @@ xyplot(surv ~ time | strat_t + strat_n, data = nd, groups = randarm,
        xlab = "Time (in days)",
        par.settings = simpleTheme(col=col),
        auto.key = list(text = levels(nd$randarm), 
-                       points = FALSE, lines = TRUE))
+                       points = FALSE, lines = TRUE, space = "top"))
 
 ## ----mtram-CAO_DFS-------------------------------------------------------
 ### convert "exact" event dates to interval-censoring (+/- one day)
@@ -438,122 +748,84 @@ CAOsurv$iDFS2 <- tmp
 
 ## ----mtram-CAO_SR, cache = TRUE------------------------------------------
 CAO_SR <- Survreg(iDFS2 ~ randarm, data = CAOsurv)
-CAO_SR_mtram_s <- mtram(CAO_SR, ~ (1 | Block), data = CAOsurv,
-                        standardise = TRUE, Hessian = TRUE)
-logLik(CAO_SR_mtram_s)
-(cf <- coef(CAO_SR_mtram_s))
+CAO_SR_mtram <- mtram(CAO_SR, ~ (1 | Block), data = CAOsurv)
+logLik(CAO_SR_mtram)
+(cf <- coef(CAO_SR_mtram))
 (OR <- exp(-cf["randarm5-FU + Oxaliplatin"] / sqrt(cf["gamma1"]^2 + 1)))
 
 ## ----mtram-CAO-CI--------------------------------------------------------
-S <- solve(CAO_SR_mtram_s$Hessian)
-sqrt(diag(S))
-rbeta <- rmvnorm(10000, mean = coef(CAO_SR_mtram_s), 
+S <- vcov(CAO_SR_mtram)
+# sqrt(diag(S))
+rbeta <- rmvnorm(10000, mean = coef(CAO_SR_mtram), 
                  sigma = S)
-s <- rbeta[,ncol(rbeta)]
-rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
+s <- rbeta[, ncol(rbeta)]
+rbeta <- rbeta[, -ncol(rbeta)] / sqrt(s^2 + 1)
 quantile(exp(-rbeta[, ncol(rbeta)]), prob = c(.025, .5, .975))
 
 ## ----mtram-CAO_SR_2, cache = TRUE----------------------------------------
 CAO_SR_2 <- Survreg(iDFS2 | 0 + strat_n:strat_t ~ randarm, data = CAOsurv)
-CAO_SR_2_mtram_s <- mtram(CAO_SR_2, ~ (1 | Block), data = CAOsurv,
-                          standardise = TRUE, Hessian  = TRUE)
-logLik(CAO_SR_2_mtram_s)
-(cf <- coef(CAO_SR_2_mtram_s))
+CAO_SR_2_mtram <- mtram(CAO_SR_2, ~ (1 | Block), data = CAOsurv)
+logLik(CAO_SR_2_mtram)
+(cf <- coef(CAO_SR_2_mtram))
 (OR_2 <- exp(-cf["randarm5-FU + Oxaliplatin"] / sqrt(cf["gamma1"]^2 + 1)))
 
 ## ----mtram-CAO-CI-2, echo = FALSE----------------------------------------
-H <- CAO_SR_2_mtram_s$Hessian
-S <- solve(H + .01 * diag(nrow(H)))
-sqrt(diag(S))
-rbeta <- rmvnorm(10000, mean = coef(CAO_SR_2_mtram_s), 
+S <- vcov(CAO_SR_2_mtram)
+rbeta <- rmvnorm(10000, mean = coef(CAO_SR_2_mtram), 
+                 sigma = S)
+s <- rbeta[, ncol(rbeta)]
+rbeta <- rbeta[, -ncol(rbeta)] / sqrt(s^2 + 1)
+quantile(exp(-rbeta[, ncol(rbeta)]), prob = c(.025, .5, .975))
+
+## ----mtram-CAO_Cox_2, cache = TRUE---------------------------------------
+CAO_Cox_2 <- Coxph(iDFS2 | 0 + strat_n:strat_t ~ randarm, data = CAOsurv, 
+                   support = c(1, 1700), log_first = TRUE, order = 4)
+logLik(CAO_Cox_2)
+CAO_Cox_2_mtram <- mtram(CAO_Cox_2, ~ (1 | Block), data = CAOsurv)
+logLik(CAO_Cox_2_mtram)
+coef(CAO_Cox_2_mtram)
+
+## ----mtram-CAO-CI-3, echo = FALSE----------------------------------------
+S <- vcov(CAO_Cox_2_mtram)
+rbeta <- rmvnorm(10000, mean = coef(CAO_Cox_2_mtram), 
                  sigma = S)
 s <- rbeta[,ncol(rbeta)]
 rbeta <- rbeta[,-ncol(rbeta)] / sqrt(s^2 + 1)
-quantile(exp(-rbeta[, ncol(rbeta)]), prob = c(.025, .5, .975))
+quantile(exp(rbeta[, ncol(rbeta)]), prob = c(.025, .5, .975))
 
-## ----mtram-CAO-coxme-----------------------------------------------------
-library("coxme")
-m <- coxme(DFS ~ randarm + (1 | Block), data = CAOsurv)
-summary(m)
-sd <- sqrt(diag(vcov(m)))
-exp(coef(m) + c(-1, 0, 1) * qnorm(.975) * sd)
+## ----mtram-CAO_PI--------------------------------------------------------
+nd <- CAOsurv[1:2, ]
+tmp <- CAO_Cox_2
+tmp$coef <- coef(CAO_Cox_2_mtram)[-22] / sqrt(coef(CAO_Cox_2_mtram)[22]^2 + 1)
+(CAO_Cox_PI <- PI(tmp, newdata = nd[2, ], reference = nd[1, ],
+                  one2one = TRUE, conf.level = .95))[1, ]
 
-## ----mtram-CHFLS, echo = FALSE-------------------------------------------
-library("TH.data")
-load(file.path(path.package(package="TH.data"), "rda", "CHFLS.rda"))
+## ----mtram-CAO_PI_man----------------------------------------------------
+ci_man <- quantile(-rbeta[, ncol(rbeta)], prob = c(.025, .5, .975))
+(CAO_Cox_PIm <- PI(ci_man, link = "minimum extreme value"))
 
-### choose neccessary variables
-org <- chfls1[, c("REGION6", "ZJ05", "ZJ06", "A35", "ZJ07", "ZJ16M", "INCRM",
-                  "JK01", "JK02", "JK20", "HY04", "HY07", "A02", "AGEGAPM", 
-                  "A07M", "A14", "A21", "A22M", "A23", "AX16", "INCAM", "SEXNOW", "ZW04")]
+## ----tramME-CAO_SR, cache = TRUE-----------------------------------------
+CAO_Cox_2_tramME <- CoxphME(iDFS2 | 0 + strat_n:strat_t ~ randarm + (1 | Block), 
+                            data = CAOsurv, log_first = TRUE)
 
-names(org) <- c("Region",
-                "Rgender",               ### gender of respondent
-                "Rage",                  ### age of respondent
-                "RagestartA",            ### age of respondent at beginning of relationship with partner A
-                "Redu",                  ### education of respondent
-                "RincomeM",              ### rounded monthly income of respondent
-                "RincomeComp",           ### inputed monthly income of respondent
-                "Rhealth",               ### health condition respondent
-                "Rheight",               ### respondent's height
-                "Rhappy",                ### respondent's happiness
-                "Rmartial",              ### respondent's marital status
-                "RhasA",                 ### R has current A partner
-                "Agender",               ### gender of partner A
-                "RAagegap",              ### age gap
-                "RAstartage",            ### age at marriage
-                "Aheight",               ### height of partner A
-                "Aedu",                  ### education of partner A
-                "AincomeM",              ### rounded partner A income
-                "AincomeEst",            ### estimated partner A income
-                "orgasm",                ### orgasm frequency
-                "AincomeComp",           ### imputed partner A income
-                "Rsexnow",               ### has sex last year
-                "Rhomosexual")           ### R is homosexual
+## ----tramME-CAO_SR-hr, cache = TRUE--------------------------------------
+exp(coef(CAO_Cox_2_tramME))
+exp(confint(CAO_Cox_2_tramME, parm = "randarm5-FU + Oxaliplatin", 
+            estimate = TRUE))
 
-### duration of partnership 
-org$RAduration <- org$Rage - org$RagestartA
+## ----echo=FALSE, eval=FALSE----------------------------------------------
+# sqrt(VarCorr(CAO_Cox_2_tramME)$Block$var)
+# coef(CAO_Cox_2_mtram)["gamma1"]
 
-### code missing values
-org$AincomeM[org$AincomeM < 0] <- NA
-org$RincomeM[org$RincomeM < 0] <- NA
-org$Aheight[org$Aheight < 0] <- NA
+## ----mtram-CAO-coxme, echo = FALSE, eval = FALSE-------------------------
+# library("coxme")
+# m <- coxme(DFS ~ randarm + (1 | Block), data = CAOsurv)
+# summary(m)
+# sd <- sqrt(diag(vcov(m)))
+# exp(coef(m) + c(-1, 0, 1) * qnorm(.975) * sd)
 
-olevels <- c("never", "rarely", "sometimes", "often", "always")
-orgA <- subset(org, Rgender == "female" & Rhomosexual != "yes" & orgasm %in% olevels)
-
-orgA$orgasm <- ordered(as.character(orgA$orgasm),
-        levels = c("never", "rarely", "sometimes", "often", "always"))
-
-orgA$Redu <- factor(as.character(orgA$Redu),
-        levels = c("univ/grad", "j col", "up mid", "low mid", "primary", "no school"))
-levels(orgA$Redu) <-  c("univ", "jcol", "upmid", "lowmid", "primary", "noschool")
-
-orgA$Aedu <- factor(as.character(orgA$Aedu),
-        levels = c("univ/grad", "j col", "up mid", "low mid", "primary", "no school"))
-
-orgA$Rhappy <- factor(as.character(orgA$Rhappy),
-        levels = c("v unhappy", "not too", "relatively", "very"))
-
-orgA$Rhealth <- factor(as.character(orgA$Rhealth),
-        levels = c("poor", "not good", "fair", "good", "excellent"))
-
-orgA$Region <- factor(as.character(orgA$Region),
-        levels = c("CentralW", "Northeast", "North", "InlandS", "CoastalE", "CoastalS"))
-
-orgA$AincomeSD <- orgA$AincomeComp/sd(orgA$AincomeComp)
-orgA$AheightSD <- orgA$Aheight/sd(orgA$Aheight)
-orgA$RageSD <- orgA$Rage/sd(orgA$Rage)
-orgA$edudiff <- as.numeric(orgA$Aedu) - as.numeric(orgA$Redu)
-orgA$edudiffSD <- orgA$edudiff/sd(orgA$edudiff, na.rm=TRUE)
-orgA$wealthdiff <- orgA$RincomeComp - orgA$AincomeComp
-orgA$wealthdiffSD <- orgA$wealthdiff/sd(orgA$wealthdiff, na.rm=TRUE)
-orgA$RAdurationSD <- orgA$RAduration/sd(orgA$RAduration, na.rm=TRUE)
-orgAtmp <- orgA[, c("orgasm", "AincomeSD", "AheightSD", "RAdurationSD",
-                 "RageSD", "edudiffSD", "wealthdiffSD", "Redu", "Rhealth",
-                 "Rhappy", "Region")]
-cc <- complete.cases(orgAtmp)
-orgAcc <- subset(orgA, cc)
+## ----sim, eval = FALSE---------------------------------------------------
+# source(system.file("simulations", "mtram_sim.R", package = "tram"), echo = TRUE)
 
 ## ----mtram-sessionInfo, echo = FALSE, results = "hide"-------------------
 sessionInfo()
@@ -587,7 +859,6 @@ pkg <- function(pkg) {
 pkg("mlt")
 pkg("tram")
 pkg("SparseGrid")
-#pkg("lme4")
 cat(c("@Manual{vign:mlt.docreg,",
              "    title = {Most Likely Transformations: The mlt Package},",
              "    author = {Torsten Hothorn},",
